[Boostheaders-commits] r40 - /

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Sat May 4 03:26:40 CEST 2013


Author: edd
Date: 2013-05-04 03:26:39 +0200 (Sat, 04 May 2013)
New Revision: 40

Modified:
   CreateBoost.sh
Log:
also scan for 'algorithm' library (needed by ExactNumCI)


Modified: CreateBoost.sh
===================================================================
--- CreateBoost.sh	2013-05-04 01:25:45 UTC (rev 39)
+++ CreateBoost.sh	2013-05-04 01:26:39 UTC (rev 40)
@@ -28,7 +28,7 @@
 ## A sanity check here before continuing:
 if [ ! -f ${boostall} ] && [ ! -d ${boostroot} ]; then
     echo "The Boost input file or directory do not exist. Exiting."
-    exit -1
+    exit 1
 fi
 
 ## DE: Needed? Can we not just overwrite?
@@ -43,7 +43,7 @@
 for prog in ${progs}; do
     if [ ! -x /usr/bin/${prog} ] && [ ! -x /usr/local/bin/${prog} ]; then
 	echo "** Program '${prog}' not found, exiting"
-	exit -1
+	exit 1
     fi
 done
     
@@ -51,7 +51,7 @@
 for dir in ${sources}; do
     if [ ! -d ${dir} ]; then
 	echo "** Source directory ${dir} not found, exiting"
-	exit -1
+	exit 1
     fi
 done
 
@@ -83,8 +83,9 @@
 # Plus foreach (cf issue ticket #2527)
 bcp --boost=${boostroot} foreach ${pkgdir}/inst/include >> bcp.log
 
 # Plus math/distributions (cf issue ticket #2533)
 bcp --boost=${boostroot} math/distributions ${pkgdir}/inst/include >> bcp.log
+bcp --boost=${boostroot} algorithm          ${pkgdir}/inst/include >> bcp.log
 
 # Plus iostream (cf issue ticket #2768) -- thia is a null-op, why?
 bcp --boost=${boostroot} iostream ${pkgdir}/inst/include >> bcp.log
@@ -83,8 +83,9 @@
 bcp --boost=${boostroot} foreach ${pkgdir}/inst/include >> bcp.log
 
-# Plus math/distributions (cf issue ticket #2533)
+# Plus math/distributions + algorithm (cf issue ticket #2533)
 bcp --boost=${boostroot} math/distributions ${pkgdir}/inst/include >> bcp.log



More information about the Boostheaders-commits mailing list